==> cloudbees-folder-5.2.1-sources.jar: com/cloudbees/hudson/plugins/folder/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.hudson.plugins.folder;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code Folder.DisplayName}: {@code Folder}.
     * 
     * @return
     *     {@code Folder}
     */
    public static String Folder_DisplayName() {
        return holder.format("Folder.DisplayName");
    }

    /**
     * Key {@code Folder.DisplayName}: {@code Folder}.
     * 
     * @return
     *     {@code Folder}
     */
    public static Localizable _Folder_DisplayName() {
        return new Localizable(holder, "Folder.DisplayName");
    }

    /**
     * Key {@code RelocateAction.permission.desc}: {@code Required to move a
     * job from one folder (or Jenkins root) to another.}.
     * 
     * @return
     *     {@code Required to move a job from one folder (or Jenkins root) to
     *     another.}
     */
    public static String RelocateAction_permission_desc() {
        return holder.format("RelocateAction.permission.desc");
    }

    /**
     * Key {@code RelocateAction.permission.desc}: {@code Required to move a
     * job from one folder (or Jenkins root) to another.}.
     * 
     * @return
     *     {@code Required to move a job from one folder (or Jenkins root) to
     *     another.}
     */
    public static Localizable _RelocateAction_permission_desc() {
        return new Localizable(holder, "RelocateAction.permission.desc");
    }

    /**
     * Key {@code Folder.DefaultPronoun}: {@code Item}.
     * 
     * @return
     *     {@code Item}
     */
    public static String Folder_DefaultPronoun() {
        return holder.format("Folder.DefaultPronoun");
    }

    /**
     * Key {@code Folder.DefaultPronoun}: {@code Item}.
     * 
     * @return
     *     {@code Item}
     */
    public static Localizable _Folder_DefaultPronoun() {
        return new Localizable(holder, "Folder.DefaultPronoun");
    }

    /**
     * Key {@code RelocateAction.displayName}: {@code Move}.
     * 
     * @return
     *     {@code Move}
     */
    public static String RelocateAction_displayName() {
        return holder.format("RelocateAction.displayName");
    }

    /**
     * Key {@code RelocateAction.displayName}: {@code Move}.
     * 
     * @return
     *     {@code Move}
     */
    public static Localizable _RelocateAction_displayName() {
        return new Localizable(holder, "RelocateAction.displayName");
    }

}

==> cloudbees-folder-5.14-sources.jar: com/cloudbees/hudson/plugins/folder/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.hudson.plugins.folder;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code Folder.DisplayName}: {@code Folder}.
     * 
     * @return
     *     {@code Folder}
     */
    public static String Folder_DisplayName() {
        return holder.format("Folder.DisplayName");
    }

    /**
     * Key {@code Folder.DisplayName}: {@code Folder}.
     * 
     * @return
     *     {@code Folder}
     */
    public static Localizable _Folder_DisplayName() {
        return new Localizable(holder, "Folder.DisplayName");
    }

    /**
     * Key {@code RelocateAction.permission.desc}: {@code Required to move a
     * job from one folder (or Jenkins root) to another.}.
     * 
     * @return
     *     {@code Required to move a job from one folder (or Jenkins root) to
     *     another.}
     */
    public static String RelocateAction_permission_desc() {
        return holder.format("RelocateAction.permission.desc");
    }

    /**
     * Key {@code RelocateAction.permission.desc}: {@code Required to move a
     * job from one folder (or Jenkins root) to another.}.
     * 
     * @return
     *     {@code Required to move a job from one folder (or Jenkins root) to
     *     another.}
     */
    public static Localizable _RelocateAction_permission_desc() {
        return new Localizable(holder, "RelocateAction.permission.desc");
    }

    /**
     * Key {@code Folder.DefaultPronoun}: {@code Item}.
     * 
     * @return
     *     {@code Item}
     */
    public static String Folder_DefaultPronoun() {
        return holder.format("Folder.DefaultPronoun");
    }

    /**
     * Key {@code Folder.DefaultPronoun}: {@code Item}.
     * 
     * @return
     *     {@code Item}
     */
    public static Localizable _Folder_DefaultPronoun() {
        return new Localizable(holder, "Folder.DefaultPronoun");
    }

    /**
     * Key {@code Folder.Description}: {@code Creates a container that stores
     * nested items in it. Useful for grouping things together. Unlike view,
     * which is just a filter, a folder creates a separate namespace, so you
     * can have multiple things of the same name as long as they are in
     * different folders.}.
     * 
     * @return
     *     {@code Creates a container that stores nested items in it. Useful for
     *     grouping things together. Unlike view, which is just a filter, a
     *     folder creates a separate namespace, so you can have multiple things
     *     of the same name as long as they are in different folders.}
     */
    public static String Folder_Description() {
        return holder.format("Folder.Description");
    }

    /**
     * Key {@code Folder.Description}: {@code Creates a container that stores
     * nested items in it. Useful for grouping things together. Unlike view,
     * which is just a filter, a folder creates a separate namespace, so you
     * can have multiple things of the same name as long as they are in
     * different folders.}.
     * 
     * @return
     *     {@code Creates a container that stores nested items in it. Useful for
     *     grouping things together. Unlike view, which is just a filter, a
     *     folder creates a separate namespace, so you can have multiple things
     *     of the same name as long as they are in different folders.}
     */
    public static Localizable _Folder_Description() {
        return new Localizable(holder, "Folder.Description");
    }

    /**
     * Key {@code RelocateAction.displayName}: {@code Move}.
     * 
     * @return
     *     {@code Move}
     */
    public static String RelocateAction_displayName() {
        return holder.format("RelocateAction.displayName");
    }

    /**
     * Key {@code RelocateAction.displayName}: {@code Move}.
     * 
     * @return
     *     {@code Move}
     */
    public static Localizable _RelocateAction_displayName() {
        return new Localizable(holder, "RelocateAction.displayName");
    }

}
